Alpha

Type Alias Alpha 

pub type Alpha<A> = GenericArray<u8, A>;
Represents the Alpha value of a certain length in the Sphinx protocol The length of the alpha value is directly dependent on the group element.

Aliased Type

#[repr(transparent)]
pub struct Alpha<A> { /* private fields */ }